# hudson

A minimal python project template that can be used for CLIs, APIs, GRPC, and other python applications.

## Usage

1. Clone this repository.
1. Replace all instances of `hudson` across the entire repository with the namespace of your project.
1. Rename the directory `hudson` with the same name too.
1. Replace `pyproject.toml` with relevant values for your project.
1. Use [pyenv](https://github.com/pyenv/pyenv) for managing your python environment.
1. Set up your virtual environment.
1. Run `./scripts/install.sh`
1. Run `./scripts/test.sh`
1. You're all set! Make this readme whatever you want now. The future is yours!
